function [mean_1, mean_2, p_val_mean, states_1, states_2, p_val, state_change_1, state_change_2, mean_var_1, mean_var_2, p_val_var] = dynamical_FC_analysis_main(data_1, data_2, winlen, k)


dim_1 = size(data_1);
dim_2 = size(data_1);

corrs_1 = [];
corrs_2 = [];
states_1 = [];
states_2 = [];
data_all_1 = [];
data_all_2 = [];
subj_id_1 = [];
subj_id_2 = [];
p_val = [];
p_val_mean = [];
mean_1 = [];
mean_2 = [];
corr_var_1 = [];
corr_var_2 = [];


disp('Computing sliding windowed correlations...')

for i = 1:dim_1(3)

    [corr_mean, corr_var] = get_sliding_window_corrs(data_1(:,:,i), winlen);
    corrs_1(:,:,:,i) = corr_mean;
    corr_var_1(:,:,i) = corr_var;
    corrs_2D = to2D(corrs_1(:,:,:,i));
    data_all_1 = vertcat(data_all_1, corrs_2D);
    subj_id_1 = vertcat(subj_id_1, i*ones(size(corrs_2D,1),1));
    
end

for i = 1:dim_2(3)

    [corr_mean, corr_var] = get_sliding_window_corrs(data_2(:,:,i), winlen);

    corrs_2(:,:,:,i) = corr_mean;
    corr_var_2(:,:,i) = corr_var;
    corrs_2D = to2D(corrs_2(:,:,:,i));
    data_all_2 = vertcat(data_all_2, corrs_2D);
    subj_id_2 = vertcat(subj_id_2, i*ones(size(corrs_2D,1),1));

end
disp('Clustering connectivity time series...');
ids_1 = kmeans(data_all_1, k);
ids_2 = kmeans(data_all_2, k);

disp('Matching connectivity states between groups...');

ids_1_relabel = ids_1;
visited = [];
for i = 1:max(ids_1)
    temp = [];
    a = mean(data_all_1(ids_1 == i, :));
    for j = 1:max(ids_2)
        b = mean(data_all_2(ids_2 == j, :));
        temp(j) = corr2(a,b);
    end
  
    temp(visited) = -1;
    m = find(temp==max(temp));
    ids_1_relabel(find(ids_1==i)) = m;
    visited = [visited m];
end

ids_1 = ids_1_relabel;

state_change_1 = abs(diff(ids_1));
state_change_2 = abs(diff(ids_2));

for i = 1:max(ids_1)
    states_1(:,:,i) =  to3D(mean(data_all_1(ids_1 == i, :)), dim_1(1));
    states_2(:,:,i) =  to3D(mean(data_all_2(ids_2 == i, :)), dim_2(1));
end

%%% dyn fc stat testing %%%

disp('2nd level analysis...');


states_1_subj = zeros(dim_1(1), dim_1(1), k, dim_1(3));
states_2_subj = zeros(dim_2(1), dim_2(1), k, dim_2(3));

for i = 1:dim_1(3)
    
    ids_temp = ids_1(subj_id_1 == i);
    data_temp = data_all_1(subj_id_1 == i, :);
    states_temp = [];
    
    for j = min(ids_temp):max(ids_temp)
        
        states_temp(:,:,j) = to3D(mean(data_temp(ids_temp == j, :)), dim_1(1));
        
    end
    
    if length(size(states_temp))<3
        states_1_subj(:,:,max(ids_temp),i) = states_temp;
    else
        states_1_subj(:,:,:,i) = states_temp;
    end
end
        

for i = 1:dim_2(3)
    
    ids_temp = ids_2(subj_id_2 == i);
    data_temp = data_all_2(subj_id_2 == i, :);
    states_temp = [];
    
    for j = min(ids_temp):max(ids_temp)
        
        states_temp(:,:,j) = to3D(mean(data_temp(ids_temp == j, :)), dim_2(1));
        
    end
    
    if length(size(states_temp))<3
        states_2_subj(:,:,max(ids_temp),i) = states_temp;
    else
        states_2_subj(:,:,:,i) = states_temp;
    end    
end

for i = 1:k
    
    for x = 1:dim_1(1)
        for y = 1:dim_1(1)
            
            a = reshape(states_1_subj(x,y,i,:),1,dim_1(3));
            b = reshape(states_2_subj(x,y,i,:),1,dim_2(3));
            a = a(find(not(a==0)));
            b = b(find(not(b==0)));
            if not(isempty(a)) && not(isempty(b))
              [h,p] = ttest2(a,b);
               p_val(x,y,i) = p;
            else
               p_val(x,y) = 1;
            end
            
        end
    end
end
        

disp('Analysis of dynamic functional connectivity variance...');

mean_var_1 = [];
mean_var_2 = [];
p_val_var = [];

for i = 1:size(corr_var_1,1);
    for j = 1:size(corr_var_1,2);
        
        a = reshape(corr_var_1(i,j,:),1,dim_1(3));            
        b = reshape(corr_var_2(i,j,:),1,dim_2(3));
        
        [h,p] = ttest(a,b);
        
        mean_var_1(i,j) = mean(a);
        mean_var_2(i,j) = mean(b);
        p_val_var(i,j) = p;
        
    end
end
    
disp('Analysis of static functional connectivity...');


%%%% static analysis %%%

all_corrs_1 = [];
all_corrs_2 = [];

for i = 1:dim_1(3)
    
    all_corrs_1(:,:,i) = corr(data_1(:,:,i)');
    
end

for i = 1:dim_2(3)
    
    all_corrs_2(:,:,i) = corr(data_2(:,:,i)');
    
end

for x = 1:dim_1(1)
    for y = 1:dim_1(1)
        
        a = reshape(all_corrs_1(x,y,:),1,dim_1(3));
        b = reshape(all_corrs_2(x,y,:),1,dim_2(3));
        mean_1(x,y) = mean(a);
        mean_2(x,y) = mean(b);
        [h,p] = ttest(a,b);
        p_val_mean(x,y) = p;
    end
end
        
         
        
        
    
    
    
    
    
    








